# -*- coding: utf-8 -*-
from tests import msg
from uamobile import *
from uamobile.willcom import WillcomUserAgent
from uamobile.factory.willcom import WillcomUserAgentFactory

def test_detect_fast():
    assert detect_fast('Mozilla/3.0(WILLCOM;SANYO/WX310SA/2;1/1/C128) NetFront/3.3,61.198.142.127') == 'willcom'

def test_useragent():
    def inner(useragent, name, vendor, model, model_version, browser_version, cache_size):
        ua = detect({'HTTP_USER_AGENT': useragent})

        assert ua.is_willcom()
        assert ua.carrier == 'WILLCOM'
        assert ua.short_carrier == 'W'
        assert ua.name == name
        assert ua.vendor == vendor
        assert ua.model == model, ua.model
        assert ua.model_version == model_version, ua.model_version
        assert ua.browser_version == browser_version, '%r expected, actual %r' % (browser_version, ua.browser_version)
        if cache_size is not None:
            assert ua.cache_size == cache_size
        else:
            assert ua.cache_size is None
        assert ua.display is not None
        assert ua.serialnumber is None
        assert ua.supports_cookie() == True

    for args in DATA:
        yield tuple([inner] + list(args))


def test_display_default():
    ua = detect({'HTTP_USER_AGENT':'Mozilla/3.0(WILLCOM;KYOCERA/WX310K/2;1.2.7.17.000000/0.1/C100) Opera 7.0'})
    assert ua.display.width != 0
    assert ua.display.height != 0
    assert ua.display.color
    assert ua.display.depth
    assert ua.display.is_vga() is False
    assert ua.display.is_qvga() is True

def test_strip_serialnumber():
    value = 'Mozilla/3.0(WILLCOM;KYOCERA/WX310K/2;1.2.7.17.000000/0.1/C100) Opera 7.0'
    ua = detect({'HTTP_USER_AGENT': value})
    assert ua.strip_serialnumber() == value


def test_is_bogus():
    def func(ip, expected):
        ua = detect({'HTTP_USER_AGENT': 'Mozilla/3.0(WILLCOM;SANYO/WX310SA/2;1/1/C128) NetFront/3.3,61.198.142.127',
                     'REMOTE_ADDR'    : ip,
                     })
        assert ua.is_willcom()
        res = ua.is_bogus()
        assert res == expected, '%s expected, actual %s' % (expected, res)

    for ip, expected in (
        ('210.230.128.224', True),
        ('61.198.128.0', False),
        ('114.20.67.0', False), # Added at 2009/12/24
        ('114.21.255.0', True), # deleted at 2010/10/6
        ('61.198.255.0', False), # Added at 2010/10/6
        ('210.255.190.0', False), # Added at 2010/10/6
        ):
        yield func, ip, expected

def test_extra_ip():
    ctxt1 = Context(extra_willcom_ips=['192.168.0.0/24'])
    ua = detect({'HTTP_USER_AGENT': 'Mozilla/3.0(WILLCOM;KYOCERA/WX310K/2;1.2.7.17.000000/0.1/C100) Opera 7.0',
                 'REMOTE_ADDR'    : '192.168.0.1',
                 },
                context=ctxt1)
    assert ua.is_willcom()
    assert ua.is_bogus() is False

    ctxt2 = Context(extra_willcom_ips=[])
    ua = detect({'HTTP_USER_AGENT': 'Mozilla/3.0(WILLCOM;KYOCERA/WX310K/2;1.2.7.17.000000/0.1/C100) Opera 7.0',
                 'REMOTE_ADDR'    : '192.168.0.1',
                 },
                context=ctxt2)
    assert ua.is_willcom()
    assert ua.is_bogus() is True


def test_my_factory():
    class MyWillcomUserAgent(WillcomUserAgent):
        def get_my_attr(self):
            return self.environ.get('HTTP_X_DOCOMO_UID')

    class MyWillcomUserAgentFactory(WillcomUserAgentFactory):
        device_class = MyWillcomUserAgent

    context = Context(willcom_factory=MyWillcomUserAgentFactory)
    ua = detect({'HTTP_USER_AGENT'  : 'Mozilla/3.0(WILLCOM;KYOCERA/WX300K/2;2.0.10.11.000000/0.1/C100) Opera/7.0',
                 'REMOTE_ADDR'      : '192.168.0.1',
                 'HTTP_X_DOCOMO_UID': 'spam',
                 },
                context=context)
    assert ua.is_willcom()
    assert isinstance(ua, MyWillcomUserAgent)
    assert ua.get_my_attr() == 'spam'


#########################
# Test data
#########################

# ua, name, vendor, model, model_version, browser_version, cache_size
DATA = (('Mozilla/3.0(DDIPOCKET;JRC/AH-J3001V,AH-J3002V/1.0/0100/c50)CNF/2.0', 'WILLCOM', 'JRC', 'AH-J3001V,AH-J3002V', '1.0', '0100', 50),
        ('Mozilla/3.0(DDIPOCKET;KYOCERA/AH-K3001V/1.7.2.70.000000/0.1/C100) Opera 7.0', 'WILLCOM', 'KYOCERA', 'AH-K3001V', '1.7.2.70.000000', '0.1', 100),
        ('Mozilla/3.0(DDIPOCKET;JRC/AH-J3003S/1.0/0100/c50)CNF/2.0', 'WILLCOM', 'JRC', 'AH-J3003S', '1.0', '0100', 50),
        ('Mozilla/3.0(WILLCOM;SANYO/WX310SA/2;1/1/C128) NetFront/3.3,61.198.142.127', 'WILLCOM', 'SANYO', 'WX310SA', '2;1', '1', 128),

        # IE on W-zero3
        ('Mozilla/4.0 (compatible; MSIE 4.01; Windows CE; SHARP/WS007SH; PPC; 480x640)', 'WILLCOM', 'SHARP', 'WS007SH', None, 'MSIE 4.01', None),

        # Opera on W-zero3
        ('Mozilla/4.0 (compatible; MSIE 6.0; Windows CE; SHARP/WS007SH; PPC; 480x640) Opera 8.60 [ja]', 'WILLCOM', 'SHARP', 'WS007SH', None, 'MSIE 6.0', None),
)



# -*- coding: utf-8 -*-
from uamobile import Context
from uamobile.factory.docomo import *
from uamobile.factory.ezweb import *
from uamobile.factory.softbank import *
from uamobile.factory.willcom import *

context = Context()

def test_docomo1():
    factory = DoCoMoUserAgentFactory()
    device = factory.create({'HTTP_USER_AGENT': 'DoCoMo/2.0 P01A(c100;TB;W24H15)'}, context)

    assert device.is_docomo()
    assert device.version == '2.0'
    assert device.model == 'P01A'
    assert device.cache_size == 100, device.cache_size
    assert device.status == 'TB'
    assert device.serialnumber is None
    assert device.card_id is None

def test_docomo2():
    factory = DoCoMoUserAgentFactory()
    device = factory.create({'HTTP_USER_AGENT': 'DoCoMo/2.0 P703i(c100;TB;W24H12;ser0123456789abcdf;icc01234567890123456789)'}, context)

    assert device.is_docomo()
    assert device.version == '2.0'
    assert device.model == 'P703i'
    assert device.cache_size == 100, device.cache_size
    assert device.status == 'TB'
    assert device.serialnumber == '0123456789abcdf'
    assert device.card_id == '01234567890123456789'

def test_ezweb1():
    factory = EZwebUserAgentFactory()
    device = factory.create({'HTTP_USER_AGENT': 'KDDI-TS2A UP.Browser/6.2.0.9 (GUI) MMP/2.0'}, context)

    assert device.is_ezweb()
    assert device.xhtml_compliant is True

def test_softbank_3g():
    factory = SoftBankUserAgentFactory()
    device = factory.create({'HTTP_USER_AGENT': 'SoftBank/1.0/913SH/SHJ001 Browser/NetFront/3.4 Profile/MIDP-2.0 Configuration/CLDC-1.1'}, context)

    assert device.is_softbank()
    assert device.model == '913SH'
    assert device.vendor == 'SH'
    assert device.vendor_version == 'J001'
    assert device.is_3g()

def test_willcom():
    factory = WillcomUserAgentFactory()
    device = factory.create({'HTTP_USER_AGENT': 'Mozilla/3.0(WILLCOM;SANYO/WX310SA/2;1/1/C128) NetFront/3.3,61.198.142.127'}, context)

    assert device.is_willcom()
    assert device.model == 'WX310SA'
    assert device.vendor == 'SANYO'
    assert device.cache_size == 128



# -*- coding: utf-8 -*-
import re
from uamobile.utils import scraper

def test_cidr():
    def func(carrier):
        res = scraper.scrape_cidr(carrier)
        assert isinstance(res, list)
        for addr in res:
            assert isinstance(addr, str)
            assert re.match(r'^\d+\.\d+\.\d+\.\d+\/\d+$', addr)

    for s in ('docomo',
              'ezweb',
              'softbank',
              'willcom',
              ):
        yield func, s



# -*- coding: utf-8 -*-
from uamobile import parser

DOCOMO = (
    ('DoCoMo/1.0/R692i/c10',
     { 'version': '1.0',
       'model'  : 'R692i',
       'c'      : 10,
       'series' : '692i',
       'html_version': '3.0',
      }),

    ('DoCoMo/1.0/P209is (Google CHTML Proxy/1.0)',
     { 'version': '1.0',
       'model'  : 'P209is',
       'series' : '209i',
       'html_version': '2.0',
       }),

    ('DoCoMo/2.0 N2001(c10;ser0123456789abcde;icc01234567890123456789)',
     { 'version': '2.0',
       'model'  : 'N2001',
       'c': 10,
       'ser'    : '0123456789abcde',
       'icc'    : '01234567890123456789',
       'series' : 'FOMA',
       'html_version': '3.0',
       },
     ),

    ('DoCoMo/2.0 P703i(c100;TB;W24H12;ser0123456789abcdf;icc01234567890123456789)',
     { 'version': '2.0',
       'model'  : 'P703i',
       'c': 100,
       'status' : 'TB',
       'ser'    : '0123456789abcdf',
       'icc'    : '01234567890123456789',
       'display_bytes': (24, 12),
       'series' : '703i',
       'html_version': '7.0',
       },
     ),

    ('DoCoMo/2.0 N902iS(c100;TB;W24H12)(compatible; moba-crawler; http://crawler.dena.jp/)',
     { 'version': '2.0',
       'model'  : 'N902iS',
       'c': 100,
       'status' : 'TB',
       'display_bytes': (24, 12),
       'series' : '902i',
       'html_version': '6.0',
       },
     ),
)

EZWEB = (
    ('KDDI-TS21 UP.Browser/6.0.2.276 (GUI) MMP/1.1',
     { 'xhtml_compliant': True,
       'device_id'      : 'TS21',
       'name'           : 'UP.Browser',
       'version'        : '6.0.2.276 (GUI)',
       'server'         : 'MMP/1.1',
       },
     ),
    ('KDDI-TS3A UP.Browser/6.2.0.11.2.1 (GUI) MMP/2.0, Mozilla/4.08 (MobilePhone; NMCS/3.3) NetFront/3.3',
     { 'xhtml_compliant': True,
       'device_id'      : 'TS3A',
       'name'           : 'UP.Browser',
       'version'        : '6.2.0.11.2.1 (GUI)',
       'server'         : 'MMP/2.0',
       },
     ),
    ('UP.Browser/3.01-HI01 UP.Link/3.4.5.2',
     { 'xhtml_compliant': False,
       'device_id'      : 'HI01',
       'name'           : 'UP.Browser',
       'version'        : '3.01',
       'server'         : 'UP.Link/3.4.5.2',
       }),
)

SOFTBANK = (
    ('Vodafone/1.0/V705SH (compatible; Y!J-SRD/1.0; http://help.yahoo.co.jp/help/jp/search/indexing/indexing-27.html)',
     { 'packet_compliant': True,
       'version'         : '1.0',
       'model'           : 'V705SH',
       'vendor'          : None,
       'vendor_version'  : None,
       'serialnumber'    : None,
       'java_info'       : {}
       },
     ),

    ('Vodafone/1.0/V802SE/SEJ001/SN123456789012345 Browser/SEMC-Browser/4.1 Profile/MIDP-2.0 Configuration/CLDC-1.1',
     { 'packet_compliant': True,
       'version'         : '1.0',
       'model'           : 'V802SE',
       'vendor'          : 'SE',
       'vendor_version'  : 'J001',
       'serialnumber'    : '123456789012345',
       'java_info'       : { 'Profile': 'MIDP-2.0',
                             'Configuration': 'CLDC-1.1',
                             }
       },
     ),

    ('Vodafone/1.0/V702NK/NKJ001 Series60/2.6 Nokia6630/2.39.148 Profile/MIDP-2.0 Configuration/CLDC-1.1',
     { 'packet_compliant': True,
       'version'         : '1.0',
       'model'           : 'V702NK',
       'vendor'          : 'NK',
       'vendor_version'  : 'J001',
       'serialnumber'    : None,
       'java_info'       : { 'Profile': 'MIDP-2.0',
                             'Configuration': 'CLDC-1.1',
                             }
       },
     ),

    ('J-PHONE/4.0/J-SH51/SNJSHA3029293 SH/0001aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.0',
     { 'packet_compliant': True,
       'version'         : '4.0',
       'model'           : 'J-SH51',
       'vendor'          : 'SH',
       'vendor_version'  : '0001aa',
       'serialnumber'    : 'JSHA3029293',
       'java_info'       : { 'Profile': 'MIDP-1.0',
                             'Configuration': 'CLDC-1.0',
                             'Ext-Profile'  : 'JSCL-1.1.0',
                             }
       },
     ),

    ('J-PHONE/2.0/J-DN02',
     { 'packet_compliant': False,
       'version'         : '2.0',
       'model'           : 'J-DN02',
       'vendor'          : 'DN',
       },
     ),

    ('MOT-V980/80.2F.2E. MIB/2.2.1 Profile/MIDP-2.0 Configuration/CLDC-1.1',
     { 'packet_compliant': True,
       'vendor'          : 'MOT',
       'vendor_version'  : '80.2F.2E.',
       'java_info'       : { 'Profile': 'MIDP-2.0',
                             'Configuration': 'CLDC-1.1',
                             }
       },
     ),
)

WILLCOM = (
    ('Mozilla/3.0(WILLCOM;SANYO/WX310SA/2;1/1/C128) NetFront/3.3,61.198.142.127',
     { 'vendor'         : 'SANYO',
       'model'          : 'WX310SA',
       'model_version'  : '2;1',
       'browser_version': '1',
       'cache_size'     : 128,
       },
     ),

    ('Mozilla/4.0 (compatible; MSIE 4.01; Windows CE; SHARP/WS007SH; PPC; 480x640)',
     { 'vendor': 'SHARP',
       'model' : 'WS007SH',
       'browser_version': 'MSIE 4.01',
       'os'  : 'Windows CE',
       'arch': 'PPC',
       },
     ),
)

def _test_func(p, ua, params):
    res = p.parse(ua)
    assert isinstance(res, dict)
    for k, v in params.items():
        assert res.get(k) == v, '%r expected, actual %r' % (v, res.get(k))

def test_docomo_parser():
    p = parser.DoCoMoUserAgentParser()
    for ua, params in DOCOMO:
        yield _test_func, p, ua, params

def test_ezweb_parser():
    p = parser.EZwebUserAgentParser()
    for ua, params in EZWEB:
        yield _test_func, p, ua, params

def test_softbank_parser():
    p = parser.SoftBankUserAgentParser()
    for ua, params in SOFTBANK:
        yield _test_func, p, ua, params

def test_willcom_parser():
    p = parser.WillcomUserAgentParser()
    for ua, params in WILLCOM:
        yield _test_func, p, ua, params



# -*- coding: utf-8 -*-
from uamobile import detect, Context

def test_crawler():
    def get_test_func(docomo=False, kddi=False, softbank=False):
        def func(ip, useragent):
            device = detect({'HTTP_USER_AGENT': useragent,
                             'REMOTE_ADDR'    : ip})
            assert device.is_docomo() is docomo
            assert device.is_ezweb() is kddi
            assert device.is_softbank() is softbank
            assert device.is_crawler()
            assert device.is_bogus()
        return func

    docomo_func = get_test_func(docomo=True)
    kddi_func = get_test_func(kddi=True)
    softbank_func = get_test_func(softbank=True)

    for ip, useragent in (
        # froute
        ('60.43.36.253', 'DoCoMo/2.0 SO902i(c100;TB;W20H10) (symphonybot1.froute.jp; +http://search.froute.jp/howto/crawler.html)'),
        # DeNA
        ('202.238.103.126', 'DoCoMo/2.0 N902iS(c100;TB;W24H12)(compatible; moba-crawler; http://crawler.dena.jp/)'),
        ('202.213.221.97', 'DoCoMo/2.0 N902iS(c100;TB;W24H12)(compatible; moba-crawler; http://crawler.dena.jp/)'),
        # Crawler whose IP is valid but the useragent contains FOMA hardware ID
        ('60.43.36.253', 'DoCoMo/2.0 M702iS(c100;TB;W24H13;ser333333033303333;icc8981100000333333333F)'),
        # Google
        ('209.85.238.17', 'DoCoMo/1.0/N505i/c20/TB/W20H10 (compatible; Googlebot-Mobile/2.1; +http://www.google.com/bot.html)'),
        ('72.14.199.1', 'DoCoMo/1.0/N505i/c20/TB/W20H10 (compatible; Googlebot-Mobile/2.1; +http://www.google.com/bot.html)'),
        # Yahoo
        ('124.83.159.146', 'DoCoMo/2.0 SH902i (compatible; Y!J-SRD/1.0; http://help.yahoo.co.jp/help/jp/search/indexing/indexing-27.html)'),
        ('124.83.159.148', 'DoCoMo/2.0 SH902i (compatible; Y!J-SRD/1.0; http://help.yahoo.co.jp/help/jp/search/indexing/indexing-27.html)'),
        ('124.83.159.152', 'DoCoMo/2.0 SH902i (compatible; Y!J-SRD/1.0; http://help.yahoo.co.jp/help/jp/search/indexing/indexing-27.html)'),
        ('124.83.159.160', 'DoCoMo/2.0 SH902i (compatible; Y!J-SRD/1.0; http://help.yahoo.co.jp/help/jp/search/indexing/indexing-27.html)'),
        ('124.83.159.176', 'DoCoMo/2.0 SH902i (compatible; Y!J-SRD/1.0; http://help.yahoo.co.jp/help/jp/search/indexing/indexing-27.html)'),
        ('124.83.159.184', 'DoCoMo/2.0 SH902i (compatible; Y!J-SRD/1.0; http://help.yahoo.co.jp/help/jp/search/indexing/indexing-27.html)'),
        # livedoor
        ('203.104.254.1', 'DoCoMo/1.0/N505i/c20/TB/W20H10 (compatible; LD_mobile_bot; +http://helpguide.livedoor.com/help/search/qa/grp627)'),
        # goo
        ('210.150.10.32', 'DoCoMo/2.0 P900i(c100;TB;W24H11)(compatible; ichiro/mobile goo; +http://help.goo.ne.jp/door/crawler.html)'),
        # baidu
        ('119.63.195.1', 'DoCoMo/2.0 P05A(c100;TB;W24H15) (compatible; BaiduMobaider/1.0; +http://www.baidu.jp/spider/)'),
        ('119.63.195.1', 'DoCoMo/1.0/D506i/c20/TB/W20H10 (compatible; BaiduMobaider/1.0; +http://www.baidu.jp/spider/)'),
        ):
        yield docomo_func, ip, useragent

    for ip, useragent in (
        # livedoor
        ('203.104.254.1', 'KDDI-HI31 UP.Browser/6.2.0.5 (GUI) MMP/2.0 (compatible; LD_mobile_bot; +http://helpguide.livedoor.com/help/search/qa/grp627)'),
        # goo
        ('210.150.10.32', 'KDDI-CA31 UP.Browser/6.2.0 (GUI) (compatible; ichiro/mobile goo; +http://help.goo.ne.jp/door/crawler.html)'),
        # froute
        ('60.43.36.253', 'KDDI-SH32 UP.Browser/6.2.0.6.2 (GUI) MMP/2.0 (symphonybot1.froute.jp; +http://search.froute.jp/howto/crawler.html)'),
        # baidu
        ('119.63.195.1', 'KDDI-CA3A UP.Browser/6.2.0.13.2 (GUI) MMP/2.0 (compatible; BaiduMobaider/1.0;+http://www.baidu.jp/spider/)'),
        ):
        yield kddi_func, ip, useragent

    for ip, useragent in (
        # livedoor
        ('203.104.254.1', 'J-PHONE/3.0/J-SH10 (compatible; LD_mobile_bot; +http://helpguide.livedoor.com/help/search/qa/grp627)'),
        # goo
        ('210.150.10.32', 'Vodafone/1.0/V802SH/SHJ002 Browser/UP.Browser/7.0.2.1 (compatible; ichiro/mobile goo;+http://help.goo.ne.jp/door/crawler.html)'),
        # froute
        ('60.43.36.253', 'SoftBank/1.0/913SH/SHJ001/SN000123456789000 Browser/NetFront/3.4 Profile/MIDP-2.0 (symphonybot1.froute.jp; +http://search.froute.jp/howto/crawler.html)'),
        # baidu
        ('119.63.195.1', 'SoftBank/1.0/912SH/SHJ002/SN001111111111000 Browser/NetFront/3.4 Profile/MIDP-2.0 (compatible; BaiduMobaider/1.0;+http://www.baidu.jp/spider/)'),
        ):
        yield softbank_func, ip, useragent

def test_not_crawler():
    def func(ip, useragent):
        device = detect({'HTTP_USER_AGENT': useragent,
                         'REMOTE_ADDR'    : ip})
        assert device.is_docomo()
        assert device.is_bogus()
        assert device.is_crawler() is False

    for ip, ua in (
        ('66.249.70.39', 'DoCoMo/1.0/N505i/c20/TB/W20H10 (compatible; Googlebot-Mobile/2.1; +http://www.google.com/bot.html)'),
        ):
        yield func, ip, ua


def test_extra_ip():
    ctxt1 = Context(extra_crawler_ips=['192.168.0.0/24'])
    ua = detect({'HTTP_USER_AGENT': 'Mozilla/3.0(WILLCOM;KYOCERA/WX310K/2;1.2.7.17.000000/0.1/C100) Opera 7.0',
                 'REMOTE_ADDR'    : '192.168.0.1',
                 },
                context=ctxt1)
    assert ua.is_willcom()
    assert ua.is_crawler() is True
    assert ua.is_bogus() is True

    ctxt2 = Context(extra_crawler_ips=[])
    ua = detect({'HTTP_USER_AGENT': 'Mozilla/3.0(WILLCOM;KYOCERA/WX310K/2;1.2.7.17.000000/0.1/C100) Opera 7.0',
                 'REMOTE_ADDR'    : '192.168.0.1',
                 },
                context=ctxt2)
    assert ua.is_willcom()
    assert ua.is_crawler() is False
    assert ua.is_bogus() is True



# -*- coding: utf-8 -*-
from uamobile import cidr

def test_get_ip_addrs():
    def func(carrier):
        addrs = cidr.get_ip_addrs(carrier)
        assert isinstance(addrs, list)
        for addr in addrs:
            assert isinstance(addr, str)

    for c in ('docomo',
              'ezweb',
              'softbank',
              'willcom',
              'crawler',
              'nonmobile',
              # case insensitive
              'DoCoMo',
              'EZWeb',
              'SoftBank',
              'WILLCOM',
              'Crawler',
              'NonMobile',
              ):
        yield func, c

def test_get_ip_addrs_error():
    try:
        cidr.get_ip_addrs('spam')
    except ValueError:
        pass
    else:
        assert False

def test_get_ip():
    def func(carrier):
        addrs = cidr.get_ip(carrier)
        assert isinstance(addrs, list)
        for addr in addrs:
            assert isinstance(addr, cidr.IP)

    for c in ('docomo',
              'ezweb',
              'softbank',
              'willcom',
              'crawler',
              'nonmobile',
              # case insensitive
              'DoCoMo',
              'EZWeb',
              'SoftBank',
              'WILLCOM',
              'Crawler',
              'NonMobile',
              ):
        yield func, c

def test_get_ip_addrs_error():
    try:
        cidr.get_ip('spam')
    except ValueError:
        pass
    else:
        assert False



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys
import optparse
import pickle
import pprint

try:
    import simplejson
    has_json = True
except ImportError:
    has_json = False

try:
    import yaml
    has_yaml = True
except ImportError:
    has_yaml = False

from uamobile.utils import scraper

def main():
    parser = optparse.OptionParser()
    parser.add_option("-c", "--carrier", dest="carrier",
                      help="mobile jp carrier. docomo/ezweb/softbank/willcom")
    parser.add_option("-o", "--filename", dest="filename", default=None,
                      help="the output filename. if None, use sys.stdout")
    parser.add_option("-f", "--format", dest="format", default='json',
                      help="the output format. json/pickle/yaml/python")
    opts, args = parser.parse_args()

    if opts.carrier is None:
        parser.print_help()
        sys.exit(1)

    if opts.filename:
        output = open(opts.filename, "w")
    else:
        output = sys.stdout

    if opts.format == 'pickle':
        dump_func = lambda result: pickle.dump(result, output)
    elif opts.format == 'json':
        if not has_json:
            print "To use 'json' format, you need simplejson"
            sys.exit(1)
        dump_func = lambda result: simplejson.dump(result, output, ensure_ascii=False, indent=2)
    elif opts.format == 'yaml':
        if not has_yaml:
            print "To use 'yaml' format, you need PyYAML"
            sys.exit(1)
        dump_func = lambda result: yaml.dump([list(x) for x in result], output)
    elif opts.format == 'python':
        dump_func = lambda result: output.write("DATA = %s\n" % pprint.pformat(result, indent=2))
    else:
        # unsupported format
        print "unsupported format %s" % opts.format
        parser.print_help()
        sys.exit(1)

    dump_func(scraper.scrape_cidr(opts.carrier))

if __name__ == '__main__':
    main()
